﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Diagnostics;

namespace BpnEntityCommon
{
    public class BpnConnection : IDisposable
    {
        #region Instance Variables

        BpNT.Application connection;

        
        #endregion

        public BpnConnection(String firm, String mandant, String user, String passwd)
        {
            Firm = firm;
            Mandant = mandant;
            User = user;
            Password = passwd;

            connection = ConnectToBueroPlus();
        }

        protected BpNT.Application ConnectToBueroPlus()
        {
            try
            {
                BpNT.Application ret = new BpNT.Application();
                ret.Init(Firm, "", User, Password);
                ret.SelectMand(Mandant);

                return ret;
            }
            catch (Exception ex)
            {
                throw new BpnConnectionException("Unable to create connection to BpNT.Application", ex);
            }
        }

        public BpNT.AutoDataSetInfo GetDataSetInfo(String dsName)
        {
            EnsureConnectionIsValid();

            var dsInfo = connection.DataSetInfos[dsName];
            if (dsInfo == null)
                throw new ArgumentException(String.Format("Unable to find dataset '{0}'"));

            return dsInfo;
        }

        public void Dispose()
        {
            if (connection != null)
            {
                try
                {
                    BpNT.IAutoAppObject appObj = this.Connection.GetSpecialObject(BpNT.SpecialObjects.soAppObject) as BpNT.IAutoAppObject;
                    uint pid = appObj.GetAppProcessId();

                    Process proc = Process.GetProcessById((int)pid);
                    if (proc != null)
                    {
                        proc.Kill();
                    }
                }
                catch (Exception ex)
                {
                    throw new BpnConnectionException("Unable to shut down connection to BpNT.Application", ex);
                }
            }

            connection = null;
        }

        protected void EnsureConnectionIsValid()
        {
            if (connection == null)
                throw new ApplicationException("Underlying connection to BpNT.Application is invalid");
        }

        #region Properties

        public String Firm { get; set; }
        public String User { get; set; }
        public String Password { get; set; }
        public String Mandant { get; set; }

        public BpNT.Application Connection
        {
            get { return connection; }
        }

        #endregion
    }

    public class BpnConnectionException : Exception
    {
        public BpnConnectionException() : base() { }

        public BpnConnectionException(String message, Exception cause) : base(message, cause) { }
    }

}
