﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace BpnEntityCommon
{
    public abstract class BpnEntity : IDictionary<String, Object>
    {
        #region Instance Variables

        BpNT.AutoDataSet dataSet;
        
        #endregion

        public BpnEntity(BpNT.AutoDataSet dataSet)
        {
            this.dataSet = dataSet;
        }

        public Boolean IsCalcField(String key)
        {
            BpNT.AutoField field = dataSet.Fields[key];
            if (field == null)
                return false;

            return field.IsCalcField;
        }

        public String FieldType(String key)
        {
            BpNT.AutoField field = dataSet.Fields[key];
            if (field == null)
                return "Object";

            return field.FieldType;
        }

        #region Append

        public void BeginAppend()
        {
            dataSet.StartTransaction();
            dataSet.Append();
        }

        public Boolean EndAppend() 
        {
            try 
            {
                dataSet.Commit();
                return true;
            } catch (Exception ex) {
                dataSet.Rollback();
                return false;
            }
        }

        public Boolean CancelAppend()
        {
            try
            {
                dataSet.Cancel();
                return true;
            }
            catch (Exception ex)
            {
                dataSet.Rollback();
                return false;
            }
        }

        public Boolean Append(IDictionary<String, Object> data)
        {
            BeginAppend();
            Set(data);
            return EndAppend();
        }

        #endregion

        #region Edit

        public bool BeginEdit()
        {
            try
            {
                dataSet.StartTransaction();
                dataSet.Edit();
                return true;
            }
            catch (Exception ex)
            {
                dataSet.Rollback();
                return false;
            }
        }

        public Boolean EndEdit()
        {
            try
            {
                dataSet.Post();
            }
            catch (Exception ex)
            {
                dataSet.Rollback();
                return false;
            }

            return EndAppend();
        }

        public Boolean CancelEdit()
        {
            return CancelAppend();
        }

        public Boolean Edit(IDictionary<String, Object> data)
        {
            BeginEdit();
            Set(data);
            return EndEdit();
        }

        #endregion

        public bool TryGetValue(string key, out object value)
        {
            try
            {
                value = dataSet.Fields[key];
                return true;
            }
            catch (Exception ex)
            {
                value = null;
                return false;
            }
        }

        public bool ContainsKey(string key)
        {
            BpNT.AutoField field = dataSet.Fields[key];
            if (field != null)
                return true;

            return false;
        }

        public bool Contains(KeyValuePair<string, object> item)
        {
            Object value;
            if (TryGetValue(item.Key, out value) == false)
                return false;

            return item.Value.Equals(value);
        }

        public void Set(string key, object value) 
        {
            this[key] = value;
        }

        public void Add(string key, object value)
        {
            Set(key, value);
        }

        public void Set(KeyValuePair<string, object> item) 
        {
            Add(item.Key, item.Value);
        }

        public void Add(KeyValuePair<string, object> item)
        {
            Set(item);
        }

        public void Set(IDictionary<String, Object> itemDictionary)
        {
            foreach (var item in itemDictionary)
            {
                Set(item);
            }
        }

        public IEnumerator<KeyValuePair<string, object>> GetEnumerator()
        {
            IDictionary<String, Object> tmp = new Dictionary<String, Object>();
            foreach (BpNT.AutoField field in dataSet.Fields)
            {
                tmp.Add(field.Name, field.Value);
            }
            return tmp.GetEnumerator();
        }

        System.Collections.IEnumerator System.Collections.IEnumerable.GetEnumerator()
        {
            return GetEnumerator();
        }

        bool ICollection<KeyValuePair<string, object>>.IsReadOnly
        {
            get { return false; }
        }

        #region Property Generation
        /*
        public String GetCSharpProperties()
        {
            StringBuilder buffer = new StringBuilder();
            foreach (String fieldName in Keys)
            {
                buffer.Append(GetCSharpPropertyForField(fieldName));
                buffer.AppendLine();
            }

            return buffer.ToString();
        }

        public String GetCSharpPropertyForField(String fieldName)
        {
            StringBuilder buffer = new StringBuilder();
            
            BpNT.AutoField field = dataSet.Fields[fieldName];
            String typeName = GetCSharpTypeForField(fieldName);

            buffer.AppendLine(String.Format("public {0} {1} {{", typeName, fieldName));
            buffer.AppendLine(GetCSharpGetAccessorForField(fieldName));
            buffer.AppendLine("}");

            return buffer.ToString();
        }

        public String GetCSharpTypeForField(String fieldName)
        {
            BpNT.AutoField field = dataSet.Fields[fieldName];
            String t = field.FieldType;

            if (t == "String")
                return "String";

            if (t == "Boolean")
                return "Boolean";

            if (t == "AutoInc" || t == "Integer" || t == "Smallint")
                return "int";

            if (t == "Date" || t == "DateTime")
                return "DateTime";

            if (t == "Float")
                return "Double";

            return "Object";
        }

        public String GetCSharpGetAccessorForField(String fieldName)
        {
            StringBuilder buffer = new StringBuilder();
            String conversionExpression = GetCSharpConversionExpressionForField(fieldName);
            String fieldAccess = GetCSharpFieldAccess(fieldName);

            buffer.AppendLine(String.Format("\tget {{ return {0}; }}", conversionExpression));
            if (IsCalcField(fieldName) == false)
            {
                buffer.AppendLine(String.Format("\tset {{ {0} = value; }}", fieldAccess));
            }

            return buffer.ToString();
        }

        public String GetCSharpConversionExpressionForField(String fieldName) {
            String t = GetCSharpTypeForField(fieldName);
            String fieldAccess = GetCSharpFieldAccess(fieldName);

            if (t == "String")
                return String.Format("Convert.ToString({0})", fieldAccess);

            if (t == "Boolean")
                return String.Format("Convert.ToBoolean({0})", fieldAccess);
           
            if (t == "int")
                return String.Format("Convert.ToInt32({0})", fieldAccess);

            if (t == "DateTime")
                return String.Format("Convert.ToDateTime({0})", fieldAccess);

            if (t == "Double")
                return String.Format("Convert.ToDouble({0})", fieldAccess);

            return fieldAccess;
        }

        public String GetCSharpFieldAccess(String fieldName) 
        {
            return String.Format("this[\"{0}\"]", fieldName);
        }
        */
        #endregion

        #region Properties

        public BpNT.AutoDataSet DataSet
        {
            get { return dataSet; }
            set { dataSet = value; }
        }

        public object this[string key]
        {
            get { return dataSet.Fields[key].Value; }
            set { dataSet.Fields[key].Value = value; }
        }

        public ICollection<string> Keys
        {
            get {
                IList<String> fieldNames = new List<String>();
                foreach (BpNT.AutoField field in dataSet.Fields)
                {
                    fieldNames.Add(field.Name);
                }
                return fieldNames;
            }
        }

        public ICollection<object> Values
        {
            get
            {
                IList<Object> values = new List<Object>();
                foreach (BpNT.AutoField field in dataSet.Fields)
                {
                    values.Add(field.Value);
                }
                return values;
            }
        }

        public int Count
        {
            get { return dataSet.Fields.Count; }
        }

        #endregion

        #region Part of IDictionary which cannot be implemented for Buero Plus

        public bool Remove(string key) { throw new InvalidOperationException(); }

        public void Clear() { throw new InvalidOperationException(); }

        public void CopyTo(KeyValuePair<string, object>[] array, int arrayIndex) { throw new InvalidOperationException(); }

        public bool Remove(KeyValuePair<string, object> item) { throw new InvalidOperationException(); }

        #endregion


       
    }
}
