using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using BpnEntityCommon;

namespace BpnEntityCommon.Entities
{
	public partial class AdressenSet : BpnEntitySet<Adressen>
	{
		#region Static Factory for EntitySet
		
		public static readonly String DS_NAME = "Adressen";
			
		public static AdressenSet CreateInstance(BpnConnection connection)
		{
		    var adressensetInfo = connection.GetDataSetInfo(DS_NAME);
		    var adressensetDataSet = adressensetInfo.CreateDataSet();
		
		    var ret = new AdressenSet(adressensetDataSet);
		    return ret;
		}
		
		internal AdressenSet(BpNT.AutoDataSet adressenDataSet) 
			: base(adressenDataSet)
		{
			InitializeIndicesNestedClass();
		}				
		
		#endregion

		#region Indices nested Class

		protected AdressenSet.IndicesClass indices;

		protected void InitializeIndicesNestedClass() 
		{
			indices = new AdressenSet.IndicesClass(this);
		}

		public class IndicesClass
		{
			protected AdressenSet parentSet;
		
			protected AdressenSetIDIndex iDIndex;
			protected AdressenSetNrIndex nrIndex;
			protected AdressenSetNrNumIndex nrNumIndex;
			protected AdressenSetSuchBegIndex suchBegIndex;
			protected AdressenSetStatusIndex statusIndex;
			protected AdressenSetVtrNrIndex vtrNrIndex;
			protected AdressenSetHaeAdrNrIndex haeAdrNrIndex;
			protected AdressenSetBKtoNrIndex bKtoNrIndex;
			protected AdressenSetWShopIdIndex wShopIdIndex;
			protected AdressenSetAucWebIdIndex aucWebIdIndex;
			protected AdressenSetErstUmsatzIndex erstUmsatzIndex;
			protected AdressenSetLtzUmsatzIndex ltzUmsatzIndex;
			protected AdressenSetSel1Index sel1Index;
			protected AdressenSetSel2Index sel2Index;
			protected AdressenSetLtzAendIndex ltzAendIndex;
			protected AdressenSetLtzAendWShopIndex ltzAendWShopIndex;
		
			internal IndicesClass(AdressenSet parentSet)
			{
				this.parentSet = parentSet;
				InitializeIndices();
			}
		
			protected void InitializeIndices() {
				iDIndex = new AdressenSetIDIndex(parentSet.DataSet);
				nrIndex = new AdressenSetNrIndex(parentSet.DataSet);
				nrNumIndex = new AdressenSetNrNumIndex(parentSet.DataSet);
				suchBegIndex = new AdressenSetSuchBegIndex(parentSet.DataSet);
				statusIndex = new AdressenSetStatusIndex(parentSet.DataSet);
				vtrNrIndex = new AdressenSetVtrNrIndex(parentSet.DataSet);
				haeAdrNrIndex = new AdressenSetHaeAdrNrIndex(parentSet.DataSet);
				bKtoNrIndex = new AdressenSetBKtoNrIndex(parentSet.DataSet);
				wShopIdIndex = new AdressenSetWShopIdIndex(parentSet.DataSet);
				aucWebIdIndex = new AdressenSetAucWebIdIndex(parentSet.DataSet);
				erstUmsatzIndex = new AdressenSetErstUmsatzIndex(parentSet.DataSet);
				ltzUmsatzIndex = new AdressenSetLtzUmsatzIndex(parentSet.DataSet);
				sel1Index = new AdressenSetSel1Index(parentSet.DataSet);
				sel2Index = new AdressenSetSel2Index(parentSet.DataSet);
				ltzAendIndex = new AdressenSetLtzAendIndex(parentSet.DataSet);
				ltzAendWShopIndex = new AdressenSetLtzAendWShopIndex(parentSet.DataSet);
			}
		
			#region Properties
		
			/// <summary>ID</summary>
			public AdressenSetIDIndex IDIndex
			{
				get { return iDIndex; }
			}
			
			/// <summary>Nummer</summary>
			public AdressenSetNrIndex NrIndex
			{
				get { return nrIndex; }
			}
			
			/// <summary>Nummer (numerisch)</summary>
			public AdressenSetNrNumIndex NrNumIndex
			{
				get { return nrNumIndex; }
			}
			
			/// <summary>Suchbegriff</summary>
			public AdressenSetSuchBegIndex SuchBegIndex
			{
				get { return suchBegIndex; }
			}
			
			/// <summary>Status</summary>
			public AdressenSetStatusIndex StatusIndex
			{
				get { return statusIndex; }
			}
			
			/// <summary>Vertreternummer</summary>
			public AdressenSetVtrNrIndex VtrNrIndex
			{
				get { return vtrNrIndex; }
			}
			
			/// <summary>Hndleradressnummer</summary>
			public AdressenSetHaeAdrNrIndex HaeAdrNrIndex
			{
				get { return haeAdrNrIndex; }
			}
			
			/// <summary>Buchungskonto (numerisch)</summary>
			public AdressenSetBKtoNrIndex BKtoNrIndex
			{
				get { return bKtoNrIndex; }
			}
			
			/// <summary>Webshop ID</summary>
			public AdressenSetWShopIdIndex WShopIdIndex
			{
				get { return wShopIdIndex; }
			}
			
			/// <summary>Auktionsplattform ID</summary>
			public AdressenSetAucWebIdIndex AucWebIdIndex
			{
				get { return aucWebIdIndex; }
			}
			
			/// <summary>Erster Umsatz</summary>
			public AdressenSetErstUmsatzIndex ErstUmsatzIndex
			{
				get { return erstUmsatzIndex; }
			}
			
			/// <summary>Letzter Umsatz</summary>
			public AdressenSetLtzUmsatzIndex LtzUmsatzIndex
			{
				get { return ltzUmsatzIndex; }
			}
			
			/// <summary>Selektion 1</summary>
			public AdressenSetSel1Index Sel1Index
			{
				get { return sel1Index; }
			}
			
			/// <summary>Selektion 2</summary>
			public AdressenSetSel2Index Sel2Index
			{
				get { return sel2Index; }
			}
			
			/// <summary>Letzte Datensatznderung</summary>
			public AdressenSetLtzAendIndex LtzAendIndex
			{
				get { return ltzAendIndex; }
			}
			
			/// <summary>Letzte Datensatznderung (Webshop Adresse)</summary>
			public AdressenSetLtzAendWShopIndex LtzAendWShopIndex
			{
				get { return ltzAendWShopIndex; }
			}
			
		
			#endregion
		}

		public AdressenSet.IndicesClass Indices 
		{
			get { return indices; }
		}

		#endregion

	}
}
