using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using BpnEntityCommon;

namespace BpnEntityCommon.Entities
{
	public partial class HistorySet : BpnEntitySet<History>
	{
		#region Static Factory for EntitySet
		
		public static readonly String DS_NAME = "History";
			
		public static HistorySet CreateInstance(BpnConnection connection)
		{
		    var historysetInfo = connection.GetDataSetInfo(DS_NAME);
		    var historysetDataSet = historysetInfo.CreateDataSet();
		
		    var ret = new HistorySet(historysetDataSet);
		    return ret;
		}
		
		internal HistorySet(BpNT.AutoDataSet historyDataSet) 
			: base(historyDataSet)
		{
			InitializeIndicesNestedClass();
		}				
		
		#endregion

		#region Indices nested Class

		protected HistorySet.IndicesClass indices;

		protected void InitializeIndicesNestedClass() 
		{
			indices = new HistorySet.IndicesClass(this);
		}

		public class IndicesClass
		{
			protected HistorySet parentSet;
		
			protected HistorySetIDIndex iDIndex;
			protected HistorySetAdrNrIndex adrNrIndex;
			protected HistorySetBelegNrIndex belegNrIndex;
			protected HistorySetPrjNrIndex prjNrIndex;
			protected HistorySetAuftrNrIndex auftrNrIndex;
			protected HistorySetDatIndex datIndex;
			protected HistorySetVsdArtIndex vsdArtIndex;
			protected HistorySetArtNrIndex artNrIndex;
			protected HistorySetAdrNrArtNrIndex adrNrArtNrIndex;
			protected HistorySetRefIndex refIndex;
			protected HistorySetWgrNrIndex wgrNrIndex;
			protected HistorySetArtDatIndex artDatIndex;
			protected HistorySetArtNrArtDatAdrNrIndex artNrArtDatAdrNrIndex;
			protected HistorySetArtPrGrpIndex artPrGrpIndex;
			protected HistorySetVertrNrIndex vertrNrIndex;
			protected HistorySetKstNrIndex kstNrIndex;
		
			internal IndicesClass(HistorySet parentSet)
			{
				this.parentSet = parentSet;
				InitializeIndices();
			}
		
			protected void InitializeIndices() {
				iDIndex = new HistorySetIDIndex(parentSet.DataSet);
				adrNrIndex = new HistorySetAdrNrIndex(parentSet.DataSet);
				belegNrIndex = new HistorySetBelegNrIndex(parentSet.DataSet);
				prjNrIndex = new HistorySetPrjNrIndex(parentSet.DataSet);
				auftrNrIndex = new HistorySetAuftrNrIndex(parentSet.DataSet);
				datIndex = new HistorySetDatIndex(parentSet.DataSet);
				vsdArtIndex = new HistorySetVsdArtIndex(parentSet.DataSet);
				artNrIndex = new HistorySetArtNrIndex(parentSet.DataSet);
				adrNrArtNrIndex = new HistorySetAdrNrArtNrIndex(parentSet.DataSet);
				refIndex = new HistorySetRefIndex(parentSet.DataSet);
				wgrNrIndex = new HistorySetWgrNrIndex(parentSet.DataSet);
				artDatIndex = new HistorySetArtDatIndex(parentSet.DataSet);
				artNrArtDatAdrNrIndex = new HistorySetArtNrArtDatAdrNrIndex(parentSet.DataSet);
				artPrGrpIndex = new HistorySetArtPrGrpIndex(parentSet.DataSet);
				vertrNrIndex = new HistorySetVertrNrIndex(parentSet.DataSet);
				kstNrIndex = new HistorySetKstNrIndex(parentSet.DataSet);
			}
		
			#region Properties
		
			/// <summary>ID</summary>
			public HistorySetIDIndex IDIndex
			{
				get { return iDIndex; }
			}
			
			/// <summary>Adressnummer</summary>
			public HistorySetAdrNrIndex AdrNrIndex
			{
				get { return adrNrIndex; }
			}
			
			/// <summary>Belegnummer</summary>
			public HistorySetBelegNrIndex BelegNrIndex
			{
				get { return belegNrIndex; }
			}
			
			/// <summary>Projektnummer</summary>
			public HistorySetPrjNrIndex PrjNrIndex
			{
				get { return prjNrIndex; }
			}
			
			/// <summary>Auftragsnummer</summary>
			public HistorySetAuftrNrIndex AuftrNrIndex
			{
				get { return auftrNrIndex; }
			}
			
			/// <summary>Datum</summary>
			public HistorySetDatIndex DatIndex
			{
				get { return datIndex; }
			}
			
			/// <summary>Versandart</summary>
			public HistorySetVsdArtIndex VsdArtIndex
			{
				get { return vsdArtIndex; }
			}
			
			/// <summary>Artikelnummer</summary>
			public HistorySetArtNrIndex ArtNrIndex
			{
				get { return artNrIndex; }
			}
			
			/// <summary>Adress- und Artikelnummer</summary>
			public HistorySetAdrNrArtNrIndex AdrNrArtNrIndex
			{
				get { return adrNrArtNrIndex; }
			}
			
			/// <summary>Referenz</summary>
			public HistorySetRefIndex RefIndex
			{
				get { return refIndex; }
			}
			
			/// <summary>Warengruppennummer</summary>
			public HistorySetWgrNrIndex WgrNrIndex
			{
				get { return wgrNrIndex; }
			}
			
			/// <summary>Artikeldatum</summary>
			public HistorySetArtDatIndex ArtDatIndex
			{
				get { return artDatIndex; }
			}
			
			/// <summary>Artikelnummer</summary>
			public HistorySetArtNrArtDatAdrNrIndex ArtNrArtDatAdrNrIndex
			{
				get { return artNrArtDatAdrNrIndex; }
			}
			
			/// <summary>Preisgruppe</summary>
			public HistorySetArtPrGrpIndex ArtPrGrpIndex
			{
				get { return artPrGrpIndex; }
			}
			
			/// <summary>Vertreternummer</summary>
			public HistorySetVertrNrIndex VertrNrIndex
			{
				get { return vertrNrIndex; }
			}
			
			/// <summary>Kostenstellennummer</summary>
			public HistorySetKstNrIndex KstNrIndex
			{
				get { return kstNrIndex; }
			}
			
		
			#endregion
		}

		public HistorySet.IndicesClass Indices 
		{
			get { return indices; }
		}

		#endregion

	}
}
