using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using BpnEntityCommon;

namespace BpnEntityCommon.Entities
{
	public partial class VersandSet : BpnEntitySet<Versand>
	{
		#region Static Factory for EntitySet
		
		public static readonly String DS_NAME = "Versand";
			
		public static VersandSet CreateInstance(BpnConnection connection)
		{
		    var versandsetInfo = connection.GetDataSetInfo(DS_NAME);
		    var versandsetDataSet = versandsetInfo.CreateDataSet();
		
		    var ret = new VersandSet(versandsetDataSet);
		    return ret;
		}
		
		internal VersandSet(BpNT.AutoDataSet versandDataSet) 
			: base(versandDataSet)
		{
			InitializeIndicesNestedClass();
		}				
		
		#endregion

		#region Indices nested Class

		protected VersandSet.IndicesClass indices;

		protected void InitializeIndicesNestedClass() 
		{
			indices = new VersandSet.IndicesClass(this);
		}

		public class IndicesClass
		{
			protected VersandSet parentSet;
		
			protected VersandSetIDIndex iDIndex;
			protected VersandSetPktNrIndex pktNrIndex;
			protected VersandSetVsdArtLfdPktNrIndex vsdArtLfdPktNrIndex;
			protected VersandSetAdrNrIndex adrNrIndex;
			protected VersandSetAdrNrDatIndex adrNrDatIndex;
			protected VersandSetBelegNrIndex belegNrIndex;
			protected VersandSetPrjNrIndex prjNrIndex;
			protected VersandSetVsdPktNrIndex vsdPktNrIndex;
			protected VersandSetVsdAdrNrIndex vsdAdrNrIndex;
			protected VersandSetVsdBelegNrIndex vsdBelegNrIndex;
		
			internal IndicesClass(VersandSet parentSet)
			{
				this.parentSet = parentSet;
				InitializeIndices();
			}
		
			protected void InitializeIndices() {
				iDIndex = new VersandSetIDIndex(parentSet.DataSet);
				pktNrIndex = new VersandSetPktNrIndex(parentSet.DataSet);
				vsdArtLfdPktNrIndex = new VersandSetVsdArtLfdPktNrIndex(parentSet.DataSet);
				adrNrIndex = new VersandSetAdrNrIndex(parentSet.DataSet);
				adrNrDatIndex = new VersandSetAdrNrDatIndex(parentSet.DataSet);
				belegNrIndex = new VersandSetBelegNrIndex(parentSet.DataSet);
				prjNrIndex = new VersandSetPrjNrIndex(parentSet.DataSet);
				vsdPktNrIndex = new VersandSetVsdPktNrIndex(parentSet.DataSet);
				vsdAdrNrIndex = new VersandSetVsdAdrNrIndex(parentSet.DataSet);
				vsdBelegNrIndex = new VersandSetVsdBelegNrIndex(parentSet.DataSet);
			}
		
			#region Properties
		
			/// <summary>ID</summary>
			public VersandSetIDIndex IDIndex
			{
				get { return iDIndex; }
			}
			
			/// <summary>Paketnummer</summary>
			public VersandSetPktNrIndex PktNrIndex
			{
				get { return pktNrIndex; }
			}
			
			/// <summary>Versandart</summary>
			public VersandSetVsdArtLfdPktNrIndex VsdArtLfdPktNrIndex
			{
				get { return vsdArtLfdPktNrIndex; }
			}
			
			/// <summary>Adressnummer</summary>
			public VersandSetAdrNrIndex AdrNrIndex
			{
				get { return adrNrIndex; }
			}
			
			/// <summary>Adressnummer & Datum</summary>
			public VersandSetAdrNrDatIndex AdrNrDatIndex
			{
				get { return adrNrDatIndex; }
			}
			
			/// <summary>Belegnummer</summary>
			public VersandSetBelegNrIndex BelegNrIndex
			{
				get { return belegNrIndex; }
			}
			
			/// <summary>Projektnummer</summary>
			public VersandSetPrjNrIndex PrjNrIndex
			{
				get { return prjNrIndex; }
			}
			
			/// <summary>Paketnummer</summary>
			public VersandSetVsdPktNrIndex VsdPktNrIndex
			{
				get { return vsdPktNrIndex; }
			}
			
			/// <summary>Adressnummer</summary>
			public VersandSetVsdAdrNrIndex VsdAdrNrIndex
			{
				get { return vsdAdrNrIndex; }
			}
			
			/// <summary>Belegnummer</summary>
			public VersandSetVsdBelegNrIndex VsdBelegNrIndex
			{
				get { return vsdBelegNrIndex; }
			}
			
		
			#endregion
		}

		public VersandSet.IndicesClass Indices 
		{
			get { return indices; }
		}

		#endregion

	}
}
